+++
title = "Quote blocks with ATTR_HTML"
tags = ["quotes", "attr_html", "attr_css"]
draft = false
+++

Some text.

<style>.red-text { color: red;  }</style>

<div class="red-text">
  <div></div>

> This is a red quote.
</div>

Some more text.
